==> eiffelstudio-18.11.10.2592.tar: F_code/C13/st604.c <==
/*
 * Code for class ST_STRING_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st604.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_STRING_ROUTINES}.is_all_whitespace */
EIF_BOOLEAN F1360_11401 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	for (;;) {
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(Result == (EIF_BOOLEAN) 0)) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
		}
		if (tb1) break;
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5070[Dtype(arg1)-1086])(RTCW(arg1), loc1);
		if ((EIF_BOOLEAN) !F1360_11403(Current, ti4_1)) {
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_STRING_ROUTINES}.is_alphanumeric */
EIF_BOOLEAN F1360_11402 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tr1 = RTOSCF(4673,F941_4673,(RTCV(RTOSCF(2165,F272_2165,(Current)))));
	tb1 = F1239_10721(RTCW(tr1), arg1);
	if (tb1) {
		tb1 = '\01';
		tr1 = RTOSCF(2165,F272_2165,(Current));
		tb2 = F1091_6599(RTCW(tr1), arg1);
		if (!tb2) {
			tr1 = RTOSCF(2165,F272_2165,(Current));
			tb2 = F1091_6608(RTCW(tr1), arg1);
			tb1 = tb2;
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {ST_STRING_ROUTINES}.is_xml_space */
EIF_BOOLEAN F1360_11403 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 32L)) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 9L))) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 10L))) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 13L)));
}

void EIF_Minit604 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C13/st604.c <==
/*
 * Code for class ST_STRING_ROUTINES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "st604.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ST_STRING_ROUTINES}.is_all_whitespace */
EIF_BOOLEAN F1366_11434 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTGC;
	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
	for (;;) {
		tb1 = '\01';
		if (!(EIF_BOOLEAN)(Result == (EIF_BOOLEAN) 0)) {
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
			tb1 = (EIF_BOOLEAN) (loc1 > ti4_1);
		}
		if (tb1) break;
		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R5091[Dtype(RTCW(arg1))-1086])(arg1, loc1);
		if ((EIF_BOOLEAN) !F1366_11436(Current, ti4_1)) {
			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		}
		loc1++;
	}
	RTLE;
	return Result;
}

/* {ST_STRING_ROUTINES}.is_alphanumeric */
EIF_BOOLEAN F1366_11435 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	Result = '\0';
	tr1 = RTOSCF(4689,F941_4689, (RTCV(RTOSCF(2168,F272_2168, (Current)))));
	tb1 = F1245_10754(RTCW(tr1), arg1);
	if (tb1) {
		tb1 = '\01';
		tr1 = RTOSCF(2168,F272_2168, (Current));
		tb2 = F1091_6629(RTCW(tr1), arg1);
		if (!tb2) {
			tr1 = RTOSCF(2168,F272_2168, (Current));
			tb2 = F1091_6638(RTCW(tr1), arg1);
			tb1 = tb2;
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {ST_STRING_ROUTINES}.is_xml_space */
EIF_BOOLEAN F1366_11436 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	
	
	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 32L)) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 9L))) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 10L))) || (EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 13L)));
}

void EIF_Minit604 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
